FossButtonStatus enum

The interactive status a FossButtonController holds. The three states are mutually exclusive: idle is the normal, enabled state.

Inheritance
Available extensions

Values

idle → const FossButtonStatus

Enabled and ready. The normal resting state.

loading → const FossButtonStatus

Running work: shows a spinner and does not respond to taps.

disabled → const FossButtonStatus

Switched off: the button does not respond to taps.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FossButtonStatus>
A constant List of the values in this enum, in order of their declaration.