leading property
A widget at the start of the row (an icon, an avatar), themed as an icon and rendered at its own size.
Implementation
final Widget? leading;
A widget at the start of the row (an icon, an avatar), themed as an icon and rendered at its own size.
final Widget? leading;